/* MixtComp version 4  - july 2019
 * Copyright (C) Inria - Université de Lille - CNRS*/

/* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>
 **/

/*
 *  Project:    MixtComp
 *  Created on: August 20, 2014
 *  Authors:    Vincent KUBICKI <vincent.kubicki@inria.fr>
 **/

#ifndef STATISTIC_H
#define STATISTIC_H

#include <Statistic/MultinomialStatistic.h>
#include <Mixture/Simple/Poisson/PoissonStatistic.h>
#include "Functions.h"
#include <Statistic/ExponentialStatistic.h>
#include <Statistic/GaussianStatistic.h>
#include <Statistic/RNG.h>
#include <Statistic/UniformStatistic.h>
#include "UniformIntStatistic.h"

#endif // STATISTIC_H
